__version__ == "1.0.0"

import os
from dotenv import load_dotenv

from .lynt import *
from .user import *

# Load environment variables from the .env file
load_dotenv()

# Load cookies from environment variables
cookies = {
    '_TOKEN__DO_NOT_SHARE': os.getenv('TOKEN'),
    'temp-discord-token': os.getenv('temp-discord_token'),
    'cf_clearance': os.getenv('cf_clearance'),
}


import requests
import os
import utils.headers
import json
import utils

def edit_profile(username : str = None, bio : str = "Nothing here yet..."):
    data = {
        'bio': bio,
        'username': username
    }

    r = requests.patch('https://lyntr.com/api/profile', cookies=cookies, headers=utils.headers.profile_headers, data=data)
    return r
def get_user_profile(profileHandle):
    """
    Get a profile via thier handle
    """

    params = {
        'handle': profileHandle
    }

    r = requests.get('https://lyntr.com/api/profile', params=params, cookies=cookies, headers=utils.headers.profile_headers)
    return r
def delete_user():
    pass


import requests
import os
import json
import utils


def send_lynt(message: str, repostID: int = None):
    """
    Message - a message to send
    repostID - ID of the message to repost
    Images and reposting not supported for now
    """

    data = {
        'content': message
    }

    if repostID is not None:
        data['reposted'] = repostID

    # Send the POST request
    r = requests.post("https://lyntr.com/api/lynt", data=data, headers=utils.headers.lynt_headers, cookies=cookies)
    return r
def like_lynt(lyntID : int):
    """
    Like a lynt
    """

    data = json.dumps({
        "lyntId": lyntID
    })

    r = requests.post('https://lyntr.com/api/likelynt', cookies=cookies, headers=utils.headers.like_lynt_headers, data=data)
    return r
def delete_lynt(lyntID : int):
    """
    Delete a lynt
    """
    params = {
        'id': lyntID
    }

    r = requests.delete('https://lyntr.com/api/lynt', params=params, cookies=cookies, headers=utils.headers.delete_lynt_headers)
    return r
def comment_lynt(lyntID : int, commment : str):
    """
    Comment on a lynt
    """

    data = json.dumps({
        'id': lyntID,
        'content': commment
    })

    r = requests.post('https://lyntr.com/api/comment', cookies=cookies, headers=utils.headers.comment_lynt_headers, data=data)
    return r
def get_lynt(lyntID : int):
    r = requests.get(f"https://lyntr.com/api/lynt?id={lyntID}", cookies=cookies, headers=utils.headers.get_lynt_headers)
    return r
def get_comments_lynt(lyntID : int):
    r = requests.get(f"https://lyntr.com/api/comments?id={lyntID}", cookies=cookies, headers=utils.headers.get_lynt_headers)
    return r
def search_lynts(search):
    r = requests.get(f"https://lyntr.com/api/search?q={search}", cookies=cookies, headers=utils.headers.search_headers)
    return r



lynt_headers = {
    "User-Agent": "Mozilla/5.0 (Windows NT 10.0; rv:128.0) Gecko/20100101 Firefox/128.0",
    "Accept": "*/*",
    "Accept-Language": "en-US,en;q=0.5",
    "Referer": "https://lyntr.com/api/lynt",
    "Origin": "https://lyntr.com",
    "DNT": "1",
    "Connection": "keep-alive",
    "Sec-Fetch-Dest": "empty",
    "Sec-Fetch-Mode": "cors",
    "Sec-Fetch-Site": "same-origin",
    "Sec-GPC": "1",
}
like_lynt_headers = {
    'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; rv:128.0) Gecko/20100101 Firefox/128.0',
    'Accept': '*/*',
    'Accept-Language': 'en-US,en;q=0.5',
    # 'Accept-Encoding': 'gzip, deflate, br, zstd',
    'Referer': 'https://lyntr.com/api/likelynt',
    'Content-Type': 'text/plain;charset=UTF-8',
    'Origin': 'https://lyntr.com',
    'DNT': '1',
    'Alt-Used': 'lyntr.com',
    'Connection': 'keep-alive',
    'Sec-Fetch-Dest': 'empty',
    'Sec-Fetch-Mode': 'cors',
    'Sec-Fetch-Site': 'same-origin',
    'Sec-GPC': '1',
    'Priority': 'u=0',
    # Requests doesn't support trailers
    # 'TE': 'trailers',
}
delete_lynt_headers = {
    'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; rv:128.0) Gecko/20100101 Firefox/128.0',
    'Accept': '*/*',
    'Accept-Language': 'en-US,en;q=0.5',
    # 'Accept-Encoding': 'gzip, deflate, br, zstd',
    'Referer': 'https://lyntr.com/api/lynt?id=9037266491583488',
    'Origin': 'https://lyntr.com',
    'DNT': '1',
    'Alt-Used': 'lyntr.com',
    'Connection': 'keep-alive',
    'Sec-Fetch-Dest': 'empty',
    'Sec-Fetch-Mode': 'cors',
    'Sec-Fetch-Site': 'same-origin',
    'Sec-GPC': '1',
    'Priority': 'u=0',
    # Requests doesn't support trailers
    # 'TE': 'trailers',
}
comment_lynt_headers = {
    'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; rv:128.0) Gecko/20100101 Firefox/128.0',
    'Accept': '*/*',
    'Accept-Language': 'en-US,en;q=0.5',
    # 'Accept-Encoding': 'gzip, deflate, br, zstd',
    'Referer': 'https://lyntr.com/api/comment',
    'Content-Type': 'text/plain;charset=UTF-8',
    'Origin': 'https://lyntr.com',
    'DNT': '1',
    'Alt-Used': 'lyntr.com',
    'Connection': 'keep-alive',
    'Sec-Fetch-Dest': 'empty',
    'Sec-Fetch-Mode': 'cors',
    'Sec-Fetch-Site': 'same-origin',
    'Sec-GPC': '1',
    'Priority': 'u=0',
    # Requests doesn't support trailers
    # 'TE': 'trailers',
}
get_lynt_headers = {
    'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; rv:128.0) Gecko/20100101 Firefox/128.0',
    'Accept': '*/*',
    'Accept-Language': 'en-US,en;q=0.5',
    # 'Accept-Encoding': 'gzip, deflate, br, zstd',
    'Referer': 'https://lyntr.com/api/lynt',
    'DNT': '1',
    'Alt-Used': 'lyntr.com',
    'Connection': 'keep-alive',
    'Sec-Fetch-Dest': 'empty',
    'Sec-Fetch-Mode': 'cors',
    'Sec-Fetch-Site': 'same-origin',
    'Sec-GPC': '1',
    'Priority': 'u=0',
    # Requests doesn't support trailers
    # 'TE': 'trailers',
}
profile_headers = {
    'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; rv:128.0) Gecko/20100101 Firefox/128.0',
    'Accept': '*/*',
    'Accept-Language': 'en-US,en;q=0.5',
    # 'Accept-Encoding': 'gzip, deflate, br, zstd',
    'Referer': 'https://lyntr.com/api/profile',
    'DNT': '1',
    'Connection': 'keep-alive',
    'Sec-Fetch-Dest': 'empty',
    'Sec-Fetch-Mode': 'cors',
    'Sec-Fetch-Site': 'same-origin',
    'Sec-GPC': '1',
    'Priority': 'u=4',
    # Requests doesn't support trailers
    # 'TE': 'trailers',
}
search_headers = {
    'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; rv:128.0) Gecko/20100101 Firefox/128.0',
    'Accept': '*/*',
    'Accept-Language': 'en-US,en;q=0.5',
    # 'Accept-Encoding': 'gzip, deflate, br, zstd',
    'Referer': 'https://lyntr.com/api/search?q=!ai',
    'DNT': '1',
    'Connection': 'keep-alive',
    'Sec-Fetch-Dest': 'empty',
    'Sec-Fetch-Mode': 'cors',
    'Sec-Fetch-Site': 'same-origin',
    'Sec-GPC': '1',
    'Priority': 'u=0',
    # Requests doesn't support trailers
    # 'TE': 'trailers',
}



import requests
from requests_sse import EventSource, InvalidStatusCodeError, InvalidContentTypeError

while True:
    with EventSource("https://lyntr.com/api/sse", timeout=30) as event_source:
        try:
            for event in event_source:
                print(event)
        except InvalidStatusCodeError:
            pass
        except InvalidContentTypeError:
            pass
        except requests.RequestException:
            pass
        except KeyboardInterrupt:
            break